@@ -16,7 +16,7 @@ UR_LOOKUP = """replace(
                                 ),'''',''
                             ),'"',''
                         )
-                    similar to %s"""
+                    ~ %s"""
 
 
 
@@ -182,11 +182,7 @@ class WordForm(models.Model):
 
     def get_norm_frequency(self):
         freq = math.log(
-                    (float(self.frequency) * 1000000)/float(
-                                        sum([x.frequency
-                                                for x in
-                                                    WordForm.objects.all()]
-                                            )),10)
+                    (float(self.frequency) * 1000000)/float(WordForm.objects.all().aggregate(totcount = Sum('frequency'))['totcount']),10)
         return freq
 
     def get_neigh_density(self):
